pub struct WSImageList {
pub images_list: Vec<CloudImage>,
pub website: Arc<WebSite>,
}Expand description
Associates a list of images with the website they come from
Fields
images_list: Vec<CloudImage>website: Arc<WebSite>Implementations
Sourceimpl WSImageList
impl WSImageList
Sourcepub async fn get_images_list(
website: Arc<WebSite>,
concurrent_downloads: usize,
db: Arc<DbImageHistory>,
) -> Self
pub async fn get_images_list( website: Arc<WebSite>, concurrent_downloads: usize, db: Arc<DbImageHistory>, ) -> Self
Retrieves for this website all downloadable images and makes an
ImageList (ie an image url and an associated checksum).
Returns a WSImageList formed with the website itself and a vector of
CloudImage
pub fn is_empty(&self) -> bool